The letter said that they were two feet high, and green, and shaped like plumber's friends. Their
suction cups were on the ground, and their shafts, which were extremely flexible, usually pointed to
the sky. At the top of each shaft was a little hand with a green eye in its palm. The creatures were
friendly, and they could see in four dimensions. They pitied Earthlings for being able to see only
three. They had many wonderful things to teach Earthlings, especially about time. Billy promised to
tell what some of those wonderful things were in his next letter. Billy was working on his second
letter when the first letter was published. The second letter started out like this: The most
important thing I learned on Tralfamadore was that when a person dies he only appears to die. He is
still very much alive in the past, so it is very silly for people to cry at his funeral. All
moments, past, present and future, always have existed, always will exist. The Tralfamadorians can
look at all the different moments just that way we can look at a stretch of the Rocky Mountains, for
instance. They can see how permanent all the moments are, and they can look at any moment that
interests them. It is just an illusion we have here on Earth that one moment follows another one,
like beads on a string, and that once a moment is gone it is gone forever. When a Tralfamadorian
sees a corpse, all he thinks is that the dead person is in a bad condition in that particular
moment, but that the same person is just fine in plenty of other moments. Now, when I myself hear
that somebody is dead, I simply shrug and say what the Tralfamadorians say about dead people, which
is "so it goes.

― Kurt Vonnegut, Slaughterhouse-Five
